@@ -1,7 +1,7 @@
 $(function() {
 	$('nav ul:first-child').slicknav({
 		"prependTo" : "#mobile-nav",
-		"label" : Translation.MENU,
+		"label" : Translation.Menu,
 		"allowParentLinks" : true
 	});
 });
\ No newline at end of file
